@@ -21,70 +21,87 @@ def skip_nones(**kwargs) -> dict:
 
 
 class ContractCall(ContextMixin):
-    """ Proxy class encapsulating a contract call: contract type scheme, contract address, parameters, and amount
-    """
+    """Proxy class encapsulating a contract call: contract type scheme, contract address, parameters, and amount"""
 
-    def __init__(self, context: ExecutionContext, parameters: dict, amount: Union[int, Decimal] = 0):
-        super(ContractCall, self).__init__(context=context)
+    def __init__(self, context: ExecutionContext, parameters: dict, amount: Union[int, Decimal] = 0) -> None:
+        super().__init__(context=context)
         self.parameters = parameters
         self.amount = amount
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         res = [
-            super(ContractCall, self).__repr__(),
+            super().__repr__(),
             f'.amount\t{self.amount}',
             '\nParameters',
             pformat(self.parameters),
             '\nHelpers',
-            get_class_docstring(self.__class__)
+            get_class_docstring(self.__class__),
         ]
         return '\n'.join(res)
 
-    def with_amount(self, amount: Union[int, Decimal]):
-        """ Send funds to the contract too.
+    def with_amount(self, amount: Union[int, Decimal]) -> 'ContractCall':
+        """Set amount of funds to send with transaction to the contract.
 
         :param amount: amount in microtez (int) or tez (Decimal)
         :rtype: ContractCall
         """
-        return ContractCall(context=self.context,
-                            parameters=self.parameters,
-                            amount=amount)
+        return ContractCall(
+            context=self.context,
+            parameters=self.parameters,
+            amount=amount,
+        )
 
     def as_transaction(self) -> OperationGroup:
-        """ Get operation content
+        """Get operation content.
 
         :rtype: OperationGroup
         """
-        return OperationGroup(context=self._spawn_context()) \
-            .transaction(destination=self.address,
-                         amount=self.amount,
-                         parameters=self.parameters)
+        return OperationGroup(context=self._spawn_context()).transaction(
+            destination=self.address,
+            amount=self.amount,
+            parameters=self.parameters,
+        )
 
     @property  # type: ignore
     @deprecated(deprecated_in='3.0.0', removed_in='3.1.0', details='use `as_transaction()` instead')
     def operation_group(self) -> OperationGroup:
         return self.as_transaction().fill()
 
-    def inject(self, _async=True, preapply=True, check_result=True, num_blocks_wait=5):
-        return self.as_transaction().autofill().sign().inject(
-            _async=_async,
-            preapply=preapply,
-            check_result=check_result,
-            num_blocks_wait=num_blocks_wait)
+    def inject(self, _async=True, preapply=True, check_result=True, num_blocks_wait=5) -> OperationGroup:
+        """Send operation to blockchain."""
+        return (
+            self.as_transaction()
+            .autofill()
+            .sign()
+            .inject(
+                _async=_async,
+                preapply=preapply,
+                check_result=check_result,
+                num_blocks_wait=num_blocks_wait,
+            )
+        )
 
-    def cmdline(self):
-        """ Generate command line for tezos client.
-        """
+    def cmdline(self) -> str:
+        """Generate command line for tezos-client."""
         arg = micheline_to_michelson(self.parameters['value'], inline=True)
         source = self.key.public_key_hash()
         amount = format_tez(self.amount)
         entrypoint = self.parameters['entrypoint']
         return f'transfer {amount} from {source} to {self.address} --entrypoint \'{entrypoint}\' --arg \'{arg}\''
 
-    def interpret(self, storage=None, source=None, sender=None, amount=None, balance=None,
-                  chain_id=None, level=None, now=None, self_address=None) \
-            -> ContractCallResult:
-        """ Run code in the builtin REPL (WARNING! Not recommended for critical tasks).
+    def interpret(
+        self,
+        storage=None,
+        source=None,
+        sender=None,
+        amount=None,
+        balance=None,
+        chain_id=None,
+        level=None,
+        now=None,
+        self_address=None,
+    ) -> ContractCallResult:
+        """Run code in the builtin REPL (WARNING! Not recommended for critical tasks).
 
         :param storage: initial storage as Python object, leave None if you want to generate a dummy one
         :param source: patch SOURCE
@@ -115,7 +132,7 @@ class ContractCall(ContextMixin):
             chain_id=chain_id,
             level=level,
             now=now,
-            address=self_address
+            address=self_address,
         )
         if error:
             logger.debug('\n'.join(stdout))
@@ -123,14 +140,25 @@ class ContractCall(ContextMixin):
         res = {
             'operations': operations,
             'storage': storage,
-            'lazy_diff': lazy_diff
+            'lazy_diff': lazy_diff,
         }
-        return ContractCallResult.from_run_code(res, parameters=self.parameters, context=self.context)
+        return ContractCallResult.from_run_code(
+            res,
+            parameters=self.parameters,
+            context=self.context,
+        )
 
-    def run_code(self, storage=None,
-                 source=None, sender=None, amount=None, balance=None, chain_id=None, gas_limit=None) \
-            -> ContractCallResult:
-        """ Execute using RPC interpreter
+    def run_code(
+        self,
+        storage=None,
+        source=None,
+        sender=None,
+        amount=None,
+        balance=None,
+        chain_id=None,
+        gas_limit=None,
+    ) -> ContractCallResult:
+        """Execute using RPC interpreter.
 
         :param storage: initial storage as Python object, leave None if you want to generate a dummy one
         :param source: patch SOURCE
@@ -157,13 +185,13 @@ class ContractCall(ContextMixin):
             source=sender,
             payer=source,
             balance=str(balance or 0),
-            gas=str(gas_limit) if gas_limit is not None else None
+            gas=str(gas_limit) if gas_limit is not None else None,
         )
         res = self.shell.blocks[self.block_id].helpers.scripts.run_code.post(query)
         return ContractCallResult.from_run_code(res, parameters=self.parameters, context=self.context)
 
     def run_operation(self) -> ContractCallResult:
-        """ Simulate operation using real context
+        """Simulate operation using real context.
 
         :rtype: ContractCallResult
         """
@@ -174,7 +202,7 @@ class ContractCall(ContextMixin):
 
     @deprecated(deprecated_in='3.0.0', removed_in='3.1.0', details='use either `run_code` or `run_operation`')
     def result(self, storage=None, source=None, sender=None, gas_limit=None) -> ContractCallResult:
-        """ Simulate operation and parse the result.
+        """Simulate operation and parse the result.
 
         :param storage: Python object only. If storage is specified, `run_code` is called instead of `run_operation`.
         :param source: Can be specified for unit testing purposes
@@ -185,19 +213,26 @@ class ContractCall(ContextMixin):
         """
         if storage or source or sender or gas_limit:
             return self.run_code(storage=storage, source=source, sender=sender, gas_limit=gas_limit)
-        else:
-            return self.run_operation()
+        return self.run_operation()
 
     def storage_view(self):
-        """ Get return value of an off-chain storage view.
+        """Get return value of an off-chain storage view.
 
         :returns: Decoded parameters of a callback
         """
-        res = self.interpret()
-        return res.storage  # type: ignore
+        _, storage, stdout, error = Interpreter.run_view(
+            parameter=self.parameters['value'],
+            entrypoint=self.parameters['entrypoint'],
+            storage={'prim': 'None'},
+            context=self.context,
+        )
+        if error:
+            logger.debug('\n'.join(stdout))
+            raise error
+        return storage  # type: ignore
 
     def callback_view(self):
-        """ Get return value of an on-chain callback method
+        """Get return value of an on-chain callback method.
 
         :returns: Decoded parameters of a callback
         """
@@ -207,16 +242,18 @@ class ContractCall(ContextMixin):
             storage_ty = StorageSection.match(self.context.storage_expr)
             initial_storage = storage_ty.dummy(self.context).to_micheline_value(lazy_diff=True)
 
-        res, stdout, error = Interpreter.run_view(
+        operations, _, stdout, error = Interpreter.run_view(
             parameter=self.parameters['value'],
             entrypoint=self.parameters['entrypoint'],
             storage=initial_storage,
-            context=self.context
+            context=self.context,
         )
+        if not len(operations) == 1:
+            raise Exception('Multiple internal operations, not sure which one to pick')
         if error:
             logger.debug('\n'.join(stdout))
             raise error
-        return res
+        return operations[0]
 
     @deprecated(deprecated_in='3.0.4', removed_in='3.1.0', details='Use callback_view instead')
     def view(self):
