@@ -2,7 +2,7 @@ from binascii import hexlify
 from datetime import datetime
 from functools import lru_cache
 from time import sleep
-from typing import List, Optional
+from typing import Any, Dict, List, Optional
 
 import requests
 import simplejson as json
@@ -20,65 +20,52 @@ def make_operation_result(**kwargs):
 
 
 class ShellQuery(RpcQuery, path=''):
-
     @property
     def blocks(self):
-        """ Shortcut for `chains.main.blocks`
-        """
+        """Shortcut for `chains.main.blocks`"""
         return self.chains.main.blocks
 
     @property
     def head(self):
-        """ Shortcut for `blocks.head`
-        """
+        """Shortcut for `blocks.head`"""
         return self.blocks.head
 
     @property  # type: ignore
     @lru_cache(maxsize=None)
     def block(self):
-        """ Cached head block, useful if you just want to explore things.
-        """
+        """Cached head block, useful if you just want to explore things."""
         return self.blocks[self.head.hash()]
 
     @property
     def cycles(self):
-        """ Operate on cycles rather than blocks.
-        """
-        return CyclesQuery(
-            node=self.node,
-            path=self._wild_path + '/chains/{}/blocks',
-            params=self._params + ['main']
-        )
+        """Operate on cycles rather than blocks."""
+        return CyclesQuery(node=self.node, path=self._wild_path + '/chains/{}/blocks', params=self._params + ['main'])
 
     @property
     def voting_periods(self):
         """
         Operate on voting periods rather than blocks.
         """
-        return VotingPeriodsQuery(
-            node=self.node,
-            path=self._wild_path + '/chains/{}/blocks',
-            params=self._params + ['main']
-        )
+        return VotingPeriodsQuery(node=self.node, path=self._wild_path + '/chains/{}/blocks', params=self._params + ['main'])
 
     @property
     def contracts(self):
-        """ Shortcut for `head.context.contracts`
-        """
+        """Shortcut for `head.context.contracts`"""
         return self.head.context.contracts
 
     @property
     def mempool(self):
-        """ Shortcut for `chains.main.mempool`
-        """
+        """Shortcut for `chains.main.mempool`"""
         return self.chains.main.mempool
 
-    def wait_next_block(self,
-                        delay_sec=1,
-                        prev_hash=None,
-                        time_between_blocks: Optional[int] = None,
-                        max_iterations: Optional[int] = None):
-        """ Wait until next block is finalized.
+    def wait_next_block(
+        self,
+        delay_sec=1,
+        prev_hash=None,
+        time_between_blocks: Optional[int] = None,
+        max_iterations: Optional[int] = None,
+    ):
+        """Wait until next block is finalized.
 
         :param prev_hash: Current block hash (optional). If not set, current head is used.
         :param time_between_blocks: override the corresponding parameter from constants
@@ -97,13 +84,13 @@ class ShellQuery(RpcQuery, path=''):
                 sleep_sec = 0 if elapsed_sec > time_between_blocks else time_between_blocks - elapsed_sec
             else:
                 sleep_sec = time_between_blocks
-            logger.info('Wait %s seconds until block %s is finalized' % (sleep_sec, prev_hash,))
+            logger.info('Wait %s seconds until block %s is finalized', sleep_sec, prev_hash)
             sleep(sleep_sec)
 
         if max_iterations is None:
             max_iterations = max(1, time_between_blocks)
 
-        for i in range(max_iterations):
+        for _ in range(max_iterations):
             current_block_hash = self.head.hash()
             if current_block_hash == prev_hash:
                 sleep(delay_sec)
@@ -134,35 +121,30 @@ class ShellQuery(RpcQuery, path=''):
 
 
 class ChainQuery(RpcQuery, path='/chains/{}'):
-
     def watermark(self):
-        """ Chain watermark, hex encoded.
-        """
+        """Chain watermark, hex encoded."""
         data = self.chain_id()
         return hexlify(base58_decode(data.encode())).decode()
 
 
 class InvalidBlockQuery(RpcQuery, path='/chains/{}/invalid_blocks/{}'):
-
     def delete(self):
         return self._delete()
 
 
 class MempoolQuery(RpcQuery, path='/chains/{}/mempool'):
-
     def post(self, configuration):
-        """ Set operation filter rules.
+        """Set operation filter rules.
 
-        :param configuration: a JSON dictionary, known keys are `minimal_fees`, `minimal_nanotez_per_gas_unit`, \
-        `minimal_nanotez_per_byte`
+        :param configuration: a JSON dictionary, known keys are `minimal_fees`, `minimal_nanotez_per_gas_unit`,
+            `minimal_nanotez_per_byte`
         """
         return self._post(json=configuration)
 
 
 class PendingOperationsQuery(RpcQuery, path='/chains/{}/mempool/pending_operations'):
-
-    def __getitem__(self, item):
-        """ Search for operation in node's mempool by hash.
+    def __getitem__(self, item: str) -> Dict[str, Any]:
+        """Search for operation in node's mempool by hash.
 
         :param item: operation group hash (base58)
         """
@@ -171,48 +153,61 @@ class PendingOperationsQuery(RpcQuery, path='/chains/{}/mempool/pending_operatio
             for operation in operations:
                 if isinstance(operation, dict):
                     if operation['hash'] == item:
-                        return {**make_operation_result(status=status), **operation}
+                        return {
+                            **make_operation_result(status=status),
+                            **operation,
+                        }
                 elif isinstance(operation, list):
                     if operation[0] == item:
                         errors = operation[1].pop1('error', default=[])
-                        return {**make_operation_result(status=status, errors=errors),
-                                **operation[1],
-                                'hash': operation[0]}
+                        return {
+                            **make_operation_result(status=status, errors=errors),
+                            **operation[1],
+                            'hash': operation[0],
+                        }
                 else:
-                    assert False, operation
+                    raise Exception('Unknown operation type', operation)
         raise StopIteration
 
-    def flatten(self) -> List[dict]:
+    def flatten(self) -> List[Dict[str, Any]]:
         operations_dict = self()
         operations_list = list()
         for status, operations in operations_dict.items():
             for operation in operations:
                 if isinstance(operation, dict):
-                    operations_list.append({**make_operation_result(status=status), **operation})
+                    operations_list.append(
+                        {
+                            **make_operation_result(status=status),
+                            **operation,
+                        }
+                    )
                 elif isinstance(operation, list):
                     errors = operation[1].pop1('error', default=[])
-                    operations_list.append({**make_operation_result(status=status, errors=errors),
-                                            **operation[1],
-                                            'hash': operation[0]})
+                    operations_list.append(
+                        {
+                            **make_operation_result(status=status, errors=errors),
+                            **operation[1],
+                            'hash': operation[0],
+                        }
+                    )
                 else:
-                    assert False, operation
+                    raise Exception('Unknown operation type', operation)
         return operations_list
 
     def __repr__(self):
         res = [
             super(PendingOperationsQuery, self).__repr__(),
-            '[]' + get_attr_docstring(self.__class__, '__getitem__')
+            '[]' + get_attr_docstring(self.__class__, '__getitem__'),
         ]
         return '\n'.join(res)
 
 
 class DescribeQuery(RpcQuery, path='/describe'):
-
     def __call__(self, recurse=True):
-        """ Get RPCs documentation and input/output schema.
+        """Get RPCs documentation and input/output schema.
 
         :param recurse: Show information for child elements, default is True.
-        In some cases doesn't work without this flag.
+            In some cases doesn't work without this flag.
         """
         return super(DescribeQuery, self).__call__(recurse=recurse)
 
@@ -220,19 +215,22 @@ class DescribeQuery(RpcQuery, path='/describe'):
         res = [
             super(DescribeQuery, self).__repr__(),
             f'(){get_attr_docstring(DescribeQuery, "__call__")}',
-            'Can be followed by any path:\n.chains\n.network.connections\netc\n'
+            'Can be followed by any path:\n.chains\n.network.connections\netc\n',
         ]
         return '\n'.join(res)
 
 
 class BlockInjectionQuery(RpcQuery, path='/injection/block'):
-
     def post(self, block, timestamp=None, _async=False, force=False, chain=None):
-        """ Inject a block in the node and broadcast it.
+        """Inject a block in the node and broadcast it.
+
         The `operations` embedded in `blockHeader` might be pre-validated using a contextual RPCs from the latest block
         (e.g. '/blocks/head/context/preapply').
 
-        :param block: Json input
+        block format:
+
+        .. code-block:: python
+
             {
                 "data": <hex-encoded block header>,
                 "operations": [ [ {
@@ -240,6 +238,8 @@ class BlockInjectionQuery(RpcQuery, path='/injection/block'):
                 "data": <hex-encoded operation>
                 } ... ] ... ]
             }
+
+        :param block: JSON input
         :param _async: By default, the RPC will wait for the block to be validated before answering, \
         set True if you don't want to.
         :param force:
@@ -253,20 +253,19 @@ class BlockInjectionQuery(RpcQuery, path='/injection/block'):
                 'chain': chain,
                 'timestamp': timestamp,
             },
-            json=block
+            json=block,
         )
 
 
 class OperationInjectionQuery(RpcQuery, path='/injection/operation'):
-
     def post(self, operation, _async=False, chain=None):
-        """ Inject an operation in node and broadcast it.
+        """Inject an operation in node and broadcast it.
         The `signedOperationContents` should be constructed using a contextual RPCs from the latest block
         and signed by the client.
 
         :param operation: Hex-encoded operation data or bytes
-        :param _async: By default, the RPC will wait for the operation to be (pre-)validated before answering, \
-        set True if you don't want to.
+        :param _async: By default, the RPC will wait for the operation to be (pre-)validated before answering,
+            set True if you don't want to.
         :param chain: Optionally you can specify the chain
         :returns: ID of the operation
         """
@@ -276,18 +275,20 @@ class OperationInjectionQuery(RpcQuery, path='/injection/operation'):
         return self._post(
             params={
                 'async': _async,
-                'chain': chain
+                'chain': chain,
             },
-            json=operation
+            json=operation,
         )
 
 
 class ProtocolInjectionQuery(RpcQuery, path='/injection/protocol'):
-
     def post(self, protocol, _async=False, force=False):
-        """ Inject a protocol in node.
+        """Inject a protocol in node.
+
+        protocol format:
+
+        .. code-block:: python
 
-        :param protocol: Json input
             {
                 "expected_env_version": <integer>,
                 "components": [{
@@ -297,6 +298,8 @@ class ProtocolInjectionQuery(RpcQuery, path='/injection/protocol'):
                      ...
                 ]}
             }
+
+        :param protocol: JSON input
         :param _async:
         :param force:
         :returns: ID of the protocol
@@ -304,14 +307,13 @@ class ProtocolInjectionQuery(RpcQuery, path='/injection/protocol'):
         return self._post(
             params={
                 'async': _async,
-                'force': force
+                'force': force,
             },
-            json=protocol
+            json=protocol,
         )
 
 
 class ResponseGenerator:
-
     def __init__(self, res: requests.Response):
         self._lines = res.iter_lines()
 
@@ -320,49 +322,53 @@ class ResponseGenerator:
             yield json.loads(line.decode())
 
 
-class MonitorQuery(RpcQuery, path=['/monitor/active_chains',
-                                   '/monitor/bootstrapped',
-                                   '/monitor/commit_hash',
-                                   '/monitor/heads/{}',
-                                   '/monitor/protocols',
-                                   '/monitor/valid_blocks']):
-
+class MonitorQuery(
+    RpcQuery,
+    path=[
+        '/monitor/active_chains',
+        '/monitor/bootstrapped',
+        '/monitor/commit_hash',
+        '/monitor/heads/{}',
+        '/monitor/protocols',
+        '/monitor/valid_blocks',
+    ],
+):
     def __call__(self, *args, **kwargs):
-        return ResponseGenerator(self.node.request(
-            method='GET',
-            path=self.path,
-            params=kwargs,
-            stream=True
-        ))
+        return ResponseGenerator(
+            self.node.request(
+                method='GET',
+                path=self.path,
+                params=kwargs,
+                stream=True,
+            )
+        )
 
     def __repr__(self):
         res = [
             super(MonitorQuery, self).__repr__(),
-            'NOTE: Returned object is a generator.'
+            'NOTE: Returned object is a generator.',
         ]
         return '\n'.join(res)
 
 
 class ConnectionQuery(RpcQuery, path='/network/connections/{}'):
-
     def delete(self, wait=False):
         return self._delete(params=dict(wait=wait))
 
 
 class NetworkItems(RpcQuery, path=['/network/peers', '/network/points']):
-
     def __call__(self, _filter=None):
         return self._get(params={'filter': _filter})
 
 
 class NetworkLogQuery(RpcQuery, path=['/network/peers/{}/log', '/network/points/{}/log']):
-
     def __call__(self, monitor=False):
         if monitor:
-            return ResponseGenerator(self.node.request(
-                method='GET',
-                path=self.path,
-                stream=True
-            ))
-        else:
-            return self._get()
+            return ResponseGenerator(
+                self.node.request(
+                    method='GET',
+                    path=self.path,
+                    stream=True,
+                )
+            )
+        return self._get()
